@@ -4,10 +4,11 @@ from dash.dependencies import Input, Output, State, MATCH, ALL
 
 
 class HydroNavigation:
-    def __init__(self, hydro_name, messages_enabled, alarms_enabled): 
+    def __init__(self, hydro_name, messages_enabled, alarms_enabled, profile_enabled): 
         self.hydro_name = hydro_name
         self.messages_enabled = messages_enabled
         self.alarms_enabled = alarms_enabled
+        self.profile_enabled = profile_enabled
 
 
     # TOP NAVIGATION
@@ -160,8 +161,9 @@ class HydroNavigation:
             top_nav_list.append(self.hydro_top_navigation_alerts())
         if self.messages_enabled:
             top_nav_list.append(self.hydro_top_navigation_messages())
-        top_nav_list.append(html.Div(className="topbar-divider d-none d-sm-block"))
-        top_nav_list.append(self.hydro_top_navigation_profile())
+        if self.profile_enabled: 
+            top_nav_list.append(html.Div(className="topbar-divider d-none d-sm-block"))
+            top_nav_list.append(self.hydro_top_navigation_profile())
         top_nav_toggle = html.Div(children=[
             html.Br(),
             html.Button(id="sidebar-toggle-btn", n_clicks=0, style={"display": "none"}, className="btn btn-icon btn-transparent-dark order-1 order-lg-0 me-2 ms-lg-2 me-lg-0", children=[ 
